@@ -1,6 +1,6 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import (
     BaseBoolInt,
     BoardDefaultOrder,
@@ -12,29 +12,31 @@ from vkbottle_types.objects import (
     UsersUserMin,
 )
 
+from .base_response import BaseResponse
+
 
 class AddTopicResponse(BaseResponse):
-    response: int = None
+    response: int
 
 
 class CreateCommentResponse(BaseResponse):
-    response: int = None
+    response: int
 
 
 class GetCommentsExtendedResponse(BaseResponse):
-    response: "GetCommentsExtendedResponseModel" = None
+    response: "GetCommentsExtendedResponseModel"
 
 
 class GetCommentsResponse(BaseResponse):
-    response: "GetCommentsResponseModel" = None
+    response: "GetCommentsResponseModel"
 
 
 class GetTopicsExtendedResponse(BaseResponse):
-    response: "GetTopicsExtendedResponseModel" = None
+    response: "GetTopicsExtendedResponseModel"
 
 
 class GetTopicsResponse(BaseResponse):
-    response: "GetTopicsResponseModel" = None
+    response: "GetTopicsResponseModel"
 
 
 class GetCommentsExtendedResponseModel(BaseResponse):
