@@ -1,19 +1,21 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import (
     DonutDonatorSubscriptionInfo,
     GroupsGroupFull,
     UsersUserFull,
 )
 
+from .base_response import BaseResponse
+
 
 class GetSubscriptionResponse(BaseResponse):
-    response: DonutDonatorSubscriptionInfo = None
+    response: DonutDonatorSubscriptionInfo
 
 
 class GetSubscriptionsResponse(BaseResponse):
-    response: "GetSubscriptionsResponseModel" = None
+    response: "GetSubscriptionsResponseModel"
 
 
 class GetSubscriptionsResponseModel(BaseResponse):
