@@ -1,6 +1,6 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import (
     FaveBookmark,
     FavePage,
@@ -9,25 +9,27 @@ from vkbottle_types.objects import (
     UsersUserFull,
 )
 
+from .base_response import BaseResponse
+
 
 class AddTagResponse(BaseResponse):
-    response: FaveTag = None
+    response: FaveTag
 
 
 class GetPagesResponse(BaseResponse):
-    response: "GetPagesResponseModel" = None
+    response: "GetPagesResponseModel"
 
 
 class GetTagsResponse(BaseResponse):
-    response: "GetTagsResponseModel" = None
+    response: "GetTagsResponseModel"
 
 
 class GetExtendedResponse(BaseResponse):
-    response: "GetExtendedResponseModel" = None
+    response: "GetExtendedResponseModel"
 
 
 class GetResponse(BaseResponse):
-    response: "GetResponseModel" = None
+    response: "GetResponseModel"
 
 
 class GetPagesResponseModel(BaseResponse):
