@@ -1,27 +1,29 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import BaseBoolInt, UsersUserMin
 
+from .base_response import BaseResponse
+
 
 class AddResponse(BaseResponse):
-    response: "AddResponseModel" = None
+    response: "AddResponseModel"
 
 
 class DeleteResponse(BaseResponse):
-    response: "DeleteResponseModel" = None
+    response: "DeleteResponseModel"
 
 
 class GetListExtendedResponse(BaseResponse):
-    response: "GetListExtendedResponseModel" = None
+    response: "GetListExtendedResponseModel"
 
 
 class GetListResponse(BaseResponse):
-    response: "GetListResponseModel" = None
+    response: "GetListResponseModel"
 
 
 class IsLikedResponse(BaseResponse):
-    response: "IsLikedResponseModel" = None
+    response: "IsLikedResponseModel"
 
 
 class AddResponseModel(BaseResponse):
