@@ -1,15 +1,17 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import StatsPeriod, StatsWallpostStat
 
+from .base_response import BaseResponse
+
 
 class GetPostReachResponse(BaseResponse):
-    response: typing.List["StatsWallpostStat"] = None
+    response: typing.List["StatsWallpostStat"]
 
 
 class GetResponse(BaseResponse):
-    response: typing.List["StatsPeriod"] = None
+    response: typing.List["StatsPeriod"]
 
 
 for item in locals().copy().values():
