@@ -1,10 +1,12 @@
 import inspect
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import StatusStatus
 
+from .base_response import BaseResponse
+
 
 class GetResponse(BaseResponse):
-    response: StatusStatus = None
+    response: StatusStatus
 
 
 for item in locals().copy().values():
